@@ -69,24 +69,27 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
 
     let gen = quote! {
         mod checkout_server {
-            pub use checkout_core::dropshot::endpoint;
             pub use checkout_core::dropshot::ApiDescription;
             pub use checkout_core::dropshot::ConfigDropshot;
             pub use checkout_core::dropshot::ConfigLogging;
             pub use checkout_core::dropshot::ConfigLoggingLevel;
-            pub use checkout_core::dropshot::HttpError;
-            pub use checkout_core::dropshot::HttpResponseOk;
             pub use checkout_core::dropshot::HttpServerStarter;
-            pub use checkout_core::dropshot::RequestContext;
-            pub use checkout_core::dropshot::TypedBody;
-            pub use checkout_core::http::StatusCode;
-            pub use checkout_core::{
-                error::Error, money::Currency, Checkout, Context, ContextProvider, server::Server,
-            };
+            pub use checkout_core::error::Error;
+            pub use checkout_core::server::Server;
 
             use std::sync::Arc;
             use checkout_core::dropshot;
+            use checkout_core::dropshot::endpoint;
+            use checkout_core::dropshot::RequestContext;
+            use checkout_core::dropshot::TypedBody;
+            use checkout_core::dropshot::HttpError;
+            use checkout_core::dropshot::HttpResponseOk;
+            use checkout_core::http::StatusCode;
+            use checkout_core::checkout::Checkout;
             use checkout_core::server::CreateRequest;
+            use checkout_core::transaction::TransactionController;
+            use checkout_core::context::Context;
+            use checkout_core::context::ContextProvider;
 
             pub struct ServerContext {
                 pub context_provider: super::#server_struct_name
@@ -94,7 +97,7 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
 
             #[endpoint {
                 method = POST,
-                path = "/create",
+                path = "/checkout",
             }]
             pub async fn create_handler(
                 req_ctx: Arc<RequestContext<ServerContext>>,
@@ -114,13 +117,13 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
                         ctx.commit_transaction().await.unwrap();
                         Ok(HttpResponseOk(co))
                     }
-                    Err(_) => {
+                    Err(err) => {
                         ctx.abort_transaction().await.unwrap();
                         Err(HttpError {
                             status_code: StatusCode::BAD_REQUEST,
-                            error_code: None,
-                            external_message: "unavailable".to_string(),
-                            internal_message: "unavailable".to_string(),
+                            error_code: Some(err.code.clone()),
+                            external_message: err.message.clone(),
+                            internal_message: err.message.clone(),
                         })
                     }
                 }
